==> DateTime-Locale-1.17.tar.gz: DateTime-Locale-1.17/share/lkt.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "lkt",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "A\N{U+014b}p\N{U+00e9}tuwa\N{U+014b}\N{U+017e}i",
    "A\N{U+014b}p\N{U+00e9}tunu\N{U+014b}pa",
    "A\N{U+014b}p\N{U+00e9}tuyamni",
    "A\N{U+014b}p\N{U+00e9}tutopa",
    "A\N{U+014b}p\N{U+00e9}tuzapta\N{U+014b}",
    "Ow\N{U+00e1}\N{U+014b}gyu\N{U+017e}a\N{U+017e}api",
    "A\N{U+014b}p\N{U+00e9}tuwak\N{U+021f}a\N{U+014b}",
  ],
  day_format_narrow => [
    "W",
    "N",
    "Y",
    "T",
    "Z",
    "O",
    "A",
  ],
  day_format_wide => [
    "A\N{U+014b}p\N{U+00e9}tuwa\N{U+014b}\N{U+017e}i",
    "A\N{U+014b}p\N{U+00e9}tunu\N{U+014b}pa",
    "A\N{U+014b}p\N{U+00e9}tuyamni",
    "A\N{U+014b}p\N{U+00e9}tutopa",
    "A\N{U+014b}p\N{U+00e9}tuzapta\N{U+014b}",
    "Ow\N{U+00e1}\N{U+014b}gyu\N{U+017e}a\N{U+017e}api",
    "A\N{U+014b}p\N{U+00e9}tuwak\N{U+021f}a\N{U+014b}",
  ],
  day_stand_alone_abbreviated => [
    "A\N{U+014b}p\N{U+00e9}tuwa\N{U+014b}\N{U+017e}i",
    "A\N{U+014b}p\N{U+00e9}tunu\N{U+014b}pa",
    "A\N{U+014b}p\N{U+00e9}tuyamni",
    "A\N{U+014b}p\N{U+00e9}tutopa",
    "A\N{U+014b}p\N{U+00e9}tuzapta\N{U+014b}",
    "Ow\N{U+00e1}\N{U+014b}gyu\N{U+017e}a\N{U+017e}api",
    "A\N{U+014b}p\N{U+00e9}tuwak\N{U+021f}a\N{U+014b}",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "A\N{U+014b}p\N{U+00e9}tuwa\N{U+014b}\N{U+017e}i",
    "A\N{U+014b}p\N{U+00e9}tunu\N{U+014b}pa",
    "A\N{U+014b}p\N{U+00e9}tuyamni",
    "A\N{U+014b}p\N{U+00e9}tutopa",
    "A\N{U+014b}p\N{U+00e9}tuzapta\N{U+014b}",
    "Ow\N{U+00e1}\N{U+014b}gyu\N{U+017e}a\N{U+017e}api",
    "A\N{U+014b}p\N{U+00e9}tuwak\N{U+021f}a\N{U+014b}",
  ],
  era_abbreviated => [
    "BCE",
    "CE",
  ],
  era_narrow => [
    "BCE",
    "CE",
  ],
  era_wide => [
    "BCE",
    "CE",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Lakota",
  month_format_abbreviated => [
    "Wi\N{U+00f3}the\N{U+021f}ika W\N{U+00ed}",
    "Thiy\N{U+00f3}\N{U+021f}eyu\N{U+014b}ka W\N{U+00ed}",
    "I\N{U+0161}t\N{U+00e1}wi\N{U+010d}hayaza\N{U+014b} W\N{U+00ed}",
    "P\N{U+021f}e\N{U+017e}\N{U+00ed}t\N{U+021f}o W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}w\N{U+00e1}pet\N{U+021f}o W\N{U+00ed}",
    "W\N{U+00ed}pazuk\N{U+021f}a-wa\N{U+0161}t\N{U+00e9} W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}p\N{U+021f}\N{U+00e1}sapa W\N{U+00ed}",
    "Was\N{U+00fa}t\N{U+021f}u\N{U+014b} W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}w\N{U+00e1}pe\N{U+01e7}i W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}w\N{U+00e1}pe-kasn\N{U+00e1} W\N{U+00ed}",
    "Wan\N{U+00ed}yetu W\N{U+00ed}",
    "T\N{U+021f}ah\N{U+00e9}kap\N{U+0161}u\N{U+014b} W\N{U+00ed}",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "Wi\N{U+00f3}the\N{U+021f}ika W\N{U+00ed}",
    "Thiy\N{U+00f3}\N{U+021f}eyu\N{U+014b}ka W\N{U+00ed}",
    "I\N{U+0161}t\N{U+00e1}wi\N{U+010d}hayaza\N{U+014b} W\N{U+00ed}",
    "P\N{U+021f}e\N{U+017e}\N{U+00ed}t\N{U+021f}o W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}w\N{U+00e1}pet\N{U+021f}o W\N{U+00ed}",
    "W\N{U+00ed}pazuk\N{U+021f}a-wa\N{U+0161}t\N{U+00e9} W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}p\N{U+021f}\N{U+00e1}sapa W\N{U+00ed}",
    "Was\N{U+00fa}t\N{U+021f}u\N{U+014b} W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}w\N{U+00e1}pe\N{U+01e7}i W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}w\N{U+00e1}pe-kasn\N{U+00e1} W\N{U+00ed}",
    "Wan\N{U+00ed}yetu W\N{U+00ed}",
    "T\N{U+021f}ah\N{U+00e9}kap\N{U+0161}u\N{U+014b} W\N{U+00ed}",
  ],
  month_stand_alone_abbreviated => [
    "Wi\N{U+00f3}the\N{U+021f}ika W\N{U+00ed}",
    "Thiy\N{U+00f3}\N{U+021f}eyu\N{U+014b}ka W\N{U+00ed}",
    "I\N{U+0161}t\N{U+00e1}wi\N{U+010d}hayaza\N{U+014b} W\N{U+00ed}",
    "P\N{U+021f}e\N{U+017e}\N{U+00ed}t\N{U+021f}o W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}w\N{U+00e1}pet\N{U+021f}o W\N{U+00ed}",
    "W\N{U+00ed}pazuk\N{U+021f}a-wa\N{U+0161}t\N{U+00e9} W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}p\N{U+021f}\N{U+00e1}sapa W\N{U+00ed}",
    "Was\N{U+00fa}t\N{U+021f}u\N{U+014b} W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}w\N{U+00e1}pe\N{U+01e7}i W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}w\N{U+00e1}pe-kasn\N{U+00e1} W\N{U+00ed}",
    "Wan\N{U+00ed}yetu W\N{U+00ed}",
    "T\N{U+021f}ah\N{U+00e9}kap\N{U+0161}u\N{U+014b} W\N{U+00ed}",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Wi\N{U+00f3}the\N{U+021f}ika W\N{U+00ed}",
    "Thiy\N{U+00f3}\N{U+021f}eyu\N{U+014b}ka W\N{U+00ed}",
    "I\N{U+0161}t\N{U+00e1}wi\N{U+010d}hayaza\N{U+014b} W\N{U+00ed}",
    "P\N{U+021f}e\N{U+017e}\N{U+00ed}t\N{U+021f}o W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}w\N{U+00e1}pet\N{U+021f}o W\N{U+00ed}",
    "W\N{U+00ed}pazuk\N{U+021f}a-wa\N{U+0161}t\N{U+00e9} W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}p\N{U+021f}\N{U+00e1}sapa W\N{U+00ed}",
    "Was\N{U+00fa}t\N{U+021f}u\N{U+014b} W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}w\N{U+00e1}pe\N{U+01e7}i W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}w\N{U+00e1}pe-kasn\N{U+00e1} W\N{U+00ed}",
    "Wan\N{U+00ed}yetu W\N{U+00ed}",
    "T\N{U+021f}ah\N{U+00e9}kap\N{U+0161}u\N{U+014b} W\N{U+00ed}",
  ],
  name => "Lakota",
  native_language => "Lak\N{U+021f}\N{U+00f3}l\N{U+02bc}iyapi",
  native_name => "Lak\N{U+021f}\N{U+00f3}l\N{U+02bc}iyapi",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 32,
}

==> DateTime-Locale-1.28.tar.gz: DateTime-Locale-1.28/share/lkt.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "lkt",
  date_format_full => "EEEE, MMMM d, y",
  date_format_long => "MMMM d, y",
  date_format_medium => "MMM d, y",
  date_format_short => "M/d/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "A\N{U+014b}p\N{U+00e9}tuwa\N{U+014b}\N{U+017e}i",
    "A\N{U+014b}p\N{U+00e9}tunu\N{U+014b}pa",
    "A\N{U+014b}p\N{U+00e9}tuyamni",
    "A\N{U+014b}p\N{U+00e9}tutopa",
    "A\N{U+014b}p\N{U+00e9}tuzapta\N{U+014b}",
    "Ow\N{U+00e1}\N{U+014b}gyu\N{U+017e}a\N{U+017e}api",
    "A\N{U+014b}p\N{U+00e9}tuwak\N{U+021f}a\N{U+014b}",
  ],
  day_format_narrow => [
    "W",
    "N",
    "Y",
    "T",
    "Z",
    "O",
    "A",
  ],
  day_format_wide => [
    "A\N{U+014b}p\N{U+00e9}tuwa\N{U+014b}\N{U+017e}i",
    "A\N{U+014b}p\N{U+00e9}tunu\N{U+014b}pa",
    "A\N{U+014b}p\N{U+00e9}tuyamni",
    "A\N{U+014b}p\N{U+00e9}tutopa",
    "A\N{U+014b}p\N{U+00e9}tuzapta\N{U+014b}",
    "Ow\N{U+00e1}\N{U+014b}gyu\N{U+017e}a\N{U+017e}api",
    "A\N{U+014b}p\N{U+00e9}tuwak\N{U+021f}a\N{U+014b}",
  ],
  day_stand_alone_abbreviated => [
    "A\N{U+014b}p\N{U+00e9}tuwa\N{U+014b}\N{U+017e}i",
    "A\N{U+014b}p\N{U+00e9}tunu\N{U+014b}pa",
    "A\N{U+014b}p\N{U+00e9}tuyamni",
    "A\N{U+014b}p\N{U+00e9}tutopa",
    "A\N{U+014b}p\N{U+00e9}tuzapta\N{U+014b}",
    "Ow\N{U+00e1}\N{U+014b}gyu\N{U+017e}a\N{U+017e}api",
    "A\N{U+014b}p\N{U+00e9}tuwak\N{U+021f}a\N{U+014b}",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "A\N{U+014b}p\N{U+00e9}tuwa\N{U+014b}\N{U+017e}i",
    "A\N{U+014b}p\N{U+00e9}tunu\N{U+014b}pa",
    "A\N{U+014b}p\N{U+00e9}tuyamni",
    "A\N{U+014b}p\N{U+00e9}tutopa",
    "A\N{U+014b}p\N{U+00e9}tuzapta\N{U+014b}",
    "Ow\N{U+00e1}\N{U+014b}gyu\N{U+017e}a\N{U+017e}api",
    "A\N{U+014b}p\N{U+00e9}tuwak\N{U+021f}a\N{U+014b}",
  ],
  era_abbreviated => [
    "BCE",
    "CE",
  ],
  era_narrow => [
    "BCE",
    "CE",
  ],
  era_wide => [
    "BCE",
    "CE",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Lakota",
  month_format_abbreviated => [
    "Wi\N{U+00f3}the\N{U+021f}ika W\N{U+00ed}",
    "Thiy\N{U+00f3}\N{U+021f}eyu\N{U+014b}ka W\N{U+00ed}",
    "I\N{U+0161}t\N{U+00e1}wi\N{U+010d}hayaza\N{U+014b} W\N{U+00ed}",
    "P\N{U+021f}e\N{U+017e}\N{U+00ed}t\N{U+021f}o W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}w\N{U+00e1}pet\N{U+021f}o W\N{U+00ed}",
    "W\N{U+00ed}pazuk\N{U+021f}a-wa\N{U+0161}t\N{U+00e9} W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}p\N{U+021f}\N{U+00e1}sapa W\N{U+00ed}",
    "Was\N{U+00fa}t\N{U+021f}u\N{U+014b} W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}w\N{U+00e1}pe\N{U+01e7}i W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}w\N{U+00e1}pe-kasn\N{U+00e1} W\N{U+00ed}",
    "Wan\N{U+00ed}yetu W\N{U+00ed}",
    "T\N{U+021f}ah\N{U+00e9}kap\N{U+0161}u\N{U+014b} W\N{U+00ed}",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "Wi\N{U+00f3}the\N{U+021f}ika W\N{U+00ed}",
    "Thiy\N{U+00f3}\N{U+021f}eyu\N{U+014b}ka W\N{U+00ed}",
    "I\N{U+0161}t\N{U+00e1}wi\N{U+010d}hayaza\N{U+014b} W\N{U+00ed}",
    "P\N{U+021f}e\N{U+017e}\N{U+00ed}t\N{U+021f}o W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}w\N{U+00e1}pet\N{U+021f}o W\N{U+00ed}",
    "W\N{U+00ed}pazuk\N{U+021f}a-wa\N{U+0161}t\N{U+00e9} W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}p\N{U+021f}\N{U+00e1}sapa W\N{U+00ed}",
    "Was\N{U+00fa}t\N{U+021f}u\N{U+014b} W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}w\N{U+00e1}pe\N{U+01e7}i W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}w\N{U+00e1}pe-kasn\N{U+00e1} W\N{U+00ed}",
    "Wan\N{U+00ed}yetu W\N{U+00ed}",
    "T\N{U+021f}ah\N{U+00e9}kap\N{U+0161}u\N{U+014b} W\N{U+00ed}",
  ],
  month_stand_alone_abbreviated => [
    "Wi\N{U+00f3}the\N{U+021f}ika W\N{U+00ed}",
    "Thiy\N{U+00f3}\N{U+021f}eyu\N{U+014b}ka W\N{U+00ed}",
    "I\N{U+0161}t\N{U+00e1}wi\N{U+010d}hayaza\N{U+014b} W\N{U+00ed}",
    "P\N{U+021f}e\N{U+017e}\N{U+00ed}t\N{U+021f}o W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}w\N{U+00e1}pet\N{U+021f}o W\N{U+00ed}",
    "W\N{U+00ed}pazuk\N{U+021f}a-wa\N{U+0161}t\N{U+00e9} W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}p\N{U+021f}\N{U+00e1}sapa W\N{U+00ed}",
    "Was\N{U+00fa}t\N{U+021f}u\N{U+014b} W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}w\N{U+00e1}pe\N{U+01e7}i W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}w\N{U+00e1}pe-kasn\N{U+00e1} W\N{U+00ed}",
    "Wan\N{U+00ed}yetu W\N{U+00ed}",
    "T\N{U+021f}ah\N{U+00e9}kap\N{U+0161}u\N{U+014b} W\N{U+00ed}",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Wi\N{U+00f3}the\N{U+021f}ika W\N{U+00ed}",
    "Thiy\N{U+00f3}\N{U+021f}eyu\N{U+014b}ka W\N{U+00ed}",
    "I\N{U+0161}t\N{U+00e1}wi\N{U+010d}hayaza\N{U+014b} W\N{U+00ed}",
    "P\N{U+021f}e\N{U+017e}\N{U+00ed}t\N{U+021f}o W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}w\N{U+00e1}pet\N{U+021f}o W\N{U+00ed}",
    "W\N{U+00ed}pazuk\N{U+021f}a-wa\N{U+0161}t\N{U+00e9} W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}p\N{U+021f}\N{U+00e1}sapa W\N{U+00ed}",
    "Was\N{U+00fa}t\N{U+021f}u\N{U+014b} W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}w\N{U+00e1}pe\N{U+01e7}i W\N{U+00ed}",
    "\N{U+010c}ha\N{U+014b}w\N{U+00e1}pe-kasn\N{U+00e1} W\N{U+00ed}",
    "Wan\N{U+00ed}yetu W\N{U+00ed}",
    "T\N{U+021f}ah\N{U+00e9}kap\N{U+0161}u\N{U+014b} W\N{U+00ed}",
  ],
  name => "Lakota",
  native_language => "Lak\N{U+021f}\N{U+00f3}l\N{U+02bc}iyapi",
  native_name => "Lak\N{U+021f}\N{U+00f3}l\N{U+02bc}iyapi",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 37,
}
